@@ -877,21 +877,13 @@ chat_window_call_activate_cb (GtkWidget         *menuitem,
 	priv = GET_PRIV (window);
 
 	if (!empathy_chat_is_group_chat (priv->current_chat)) {
-		MissionControl     *mc;
 		EmpathyPrivateChat *chat;
 		EmpathyContact     *contact;
 
 		chat = EMPATHY_PRIVATE_CHAT (priv->current_chat);
 		contact = empathy_private_chat_get_contact (chat);
 
-		mc = empathy_mission_control_new ();
-		mission_control_request_channel (mc,
-						 empathy_contact_get_account (contact),
-						 TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
-						 empathy_contact_get_handle (contact),
-						 TP_HANDLE_TYPE_CONTACT,
-						 NULL, NULL);
-		g_object_unref (mc);
+		empathy_call_contact (contact);
 	}
 }
 
@@ -997,8 +989,12 @@ chat_window_conv_activate_cb (GtkWidget         *menuitem,
 	}
 
 	gtk_widget_set_sensitive (priv->menu_conv_log, log_exists);
-	g_object_set (priv->menu_conv_call, "visible", can_voip, NULL);
-	g_object_set (priv->menu_conv_call_separator, "visible", can_voip, NULL);
+#ifdef HAVE_VOIP
+	gtk_widget_set_sensitive (priv->menu_conv_call, can_voip);
+#else 
+	g_object_set (priv->menu_conv_call, "visible", FALSE, NULL);
+	g_object_set (priv->menu_conv_call_separator, "visible", FALSE, NULL);
+#endif
 }
 
 static void
@@ -1762,12 +1758,15 @@ empathy_chat_window_get_dialog (EmpathyChatWindow *window)
 
 void
 empathy_chat_window_add_chat (EmpathyChatWindow *window,
-			     EmpathyChat	      *chat)
+			      EmpathyChat	*chat)
 {
 	EmpathyChatWindowPriv *priv;
 	GtkWidget            *label;
 	GtkWidget            *child;
 
+	g_return_if_fail (window != NULL);
+	g_return_if_fail (EMPATHY_IS_CHAT (chat));
+
 	priv = GET_PRIV (window);
 
 	/* Reference the chat object */
@@ -1812,11 +1811,14 @@ empathy_chat_window_add_chat (EmpathyChatWindow *window,
 
 void
 empathy_chat_window_remove_chat (EmpathyChatWindow *window,
-				EmpathyChat	 *chat)
+				 EmpathyChat	   *chat)
 {
 	EmpathyChatWindowPriv *priv;
 	gint                  position;
 
+	g_return_if_fail (window != NULL);
+	g_return_if_fail (EMPATHY_IS_CHAT (chat));
+
 	priv = GET_PRIV (window);
 
 	position = gtk_notebook_page_num (GTK_NOTEBOOK (priv->notebook),
@@ -1832,8 +1834,8 @@ empathy_chat_window_remove_chat (EmpathyChatWindow *window,
 
 void
 empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
-			      EmpathyChatWindow *new_window,
-			      EmpathyChat       *chat)
+			       EmpathyChatWindow *new_window,
+			       EmpathyChat       *chat)
 {
 	GtkWidget *widget;
 
@@ -1863,11 +1865,14 @@ empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
 
 void
 empathy_chat_window_switch_to_chat (EmpathyChatWindow *window,
-				   EmpathyChat	    *chat)
+				    EmpathyChat	      *chat)
 {
 	EmpathyChatWindowPriv *priv;
 	gint                  page_num;
 
+	g_return_if_fail (window != NULL);
+	g_return_if_fail (EMPATHY_IS_CHAT (chat));
+
 	priv = GET_PRIV (window);
 
 	page_num = gtk_notebook_page_num (GTK_NOTEBOOK (priv->notebook),
@@ -1893,10 +1898,13 @@ empathy_chat_window_has_focus (EmpathyChatWindow *window)
 
 EmpathyChat *
 empathy_chat_window_find_chat (McAccount   *account,
-			      const gchar *id)
+			       const gchar *id)
 {
 	GList *l;
 
+	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
+	g_return_val_if_fail (!G_STR_EMPTY (id), NULL);
+
 	for (l = chat_windows; l; l = l->next) {
 		EmpathyChatWindowPriv *priv;
 		EmpathyChatWindow     *window;
