@@ -117,9 +117,12 @@ static void       status_icon_quit_cb             (GtkWidget              *windo
 						   EmpathyStatusIcon      *icon);
 static void       status_icon_show_hide_window_cb (GtkWidget              *widget,
 						   EmpathyStatusIcon      *icon);
-static void       status_icon_local_pending_cb    (EmpathyContactManager  *manager,
-						   EmpathyContact          *contact,
+static void       status_icon_pendings_changed_cb (EmpathyContactManager  *manager,
+						   EmpathyContact         *contact,
+						   EmpathyContact         *actor,
+						   guint                   reason,
 						   gchar                  *message,
+						   gboolean                is_pending,
 						   EmpathyStatusIcon      *icon);
 static void       status_icon_event_subscribe_cb  (StatusIconEvent        *event);
 static void       status_icon_event_flash_state_cb (StatusIconEvent       *event);
@@ -148,12 +151,14 @@ static void
 empathy_status_icon_init (EmpathyStatusIcon *icon)
 {
 	EmpathyStatusIconPriv *priv;
-	GList                 *pending, *l;
+	GList                 *pendings, *l;
 
 	priv = GET_PRIV (icon);
 
 	priv->icon = gtk_status_icon_new ();
 	priv->idle = empathy_idle_new ();
+	empathy_idle_set_auto_away (priv->idle, TRUE);
+	empathy_idle_set_auto_disconnect (priv->idle, TRUE);
 	priv->manager = empathy_contact_manager_new ();
 	priv->mc = empathy_mission_control_new ();
 	priv->text_filter = empathy_filter_new ("org.gnome.Empathy.Chat",
@@ -177,21 +182,25 @@ empathy_status_icon_init (EmpathyStatusIcon *icon)
 	g_signal_connect (priv->icon, "popup-menu",
 			  G_CALLBACK (status_icon_popup_menu_cb),
 			  icon);
-	g_signal_connect (priv->manager, "local-pending",
-			  G_CALLBACK (status_icon_local_pending_cb),
+	g_signal_connect (priv->manager, "pendings-changed",
+			  G_CALLBACK (status_icon_pendings_changed_cb),
 			  icon);
 
-	pending = empathy_contact_list_get_local_pending (EMPATHY_CONTACT_LIST (priv->manager));
-	for (l = pending; l; l = l->next) {
-		EmpathyContactListInfo *info;
+	pendings = empathy_contact_list_get_pendings (EMPATHY_CONTACT_LIST (priv->manager));
+	for (l = pendings; l; l = l->next) {
+		EmpathyPendingInfo *info;
 
 		info = l->data;
-		status_icon_local_pending_cb (priv->manager,
-					      info->contact,
-					      info->message,
-					      icon);
+		status_icon_pendings_changed_cb (priv->manager,
+						 info->member,
+						 info->actor,
+						 0,
+						 info->message,
+						 TRUE,
+						 icon);
+		empathy_pending_info_free (info);
 	}
-	g_list_free (pending);
+	g_list_free (pendings);
 }
 
 static void
@@ -533,34 +542,44 @@ status_icon_show_hide_window_cb (GtkWidget         *widget,
 }
 
 static void
-status_icon_local_pending_cb (EmpathyContactManager *manager,
-			      EmpathyContact         *contact,
-			      gchar                 *message,
-			      EmpathyStatusIcon     *icon)
+status_icon_pendings_changed_cb (EmpathyContactManager *manager,
+				 EmpathyContact        *contact,
+				 EmpathyContact        *actor,
+				 guint                  reason,
+				 gchar                 *message,
+				 gboolean               is_pending,
+				 EmpathyStatusIcon     *icon)
 {
 	EmpathyStatusIconPriv *priv;
 	StatusIconEvent       *event;
-	gchar                 *str;
+	GString               *str;
 	GList                 *l;
 
 	priv = GET_PRIV (icon);
 
+	if (!is_pending) {
+		/* FIXME: We should remove the event */
+		return;
+	}
+
 	for (l = priv->events; l; l = l->next) {
 		if (empathy_contact_equal (contact, ((StatusIconEvent*)l->data)->user_data)) {
 			return;
 		}
 	}
 
-	str = g_strdup_printf (_("Subscription requested for %s\n"
-				 "Message: %s"),
-			       empathy_contact_get_name (contact),
-			       message);
+	str = g_string_new (NULL);
+	g_string_printf (str, _("Subscription requested by %s"),
+			 empathy_contact_get_name (contact));	
+	if (!G_STR_EMPTY (message)) {
+		g_string_append_printf (str, _("\nMessage: %s"), message);
+	}
 
-	event = status_icon_event_new (icon, GTK_STOCK_DIALOG_QUESTION, str);
+	event = status_icon_event_new (icon, GTK_STOCK_DIALOG_QUESTION, str->str);
 	event->user_data = g_object_ref (contact);
 	event->func = status_icon_event_subscribe_cb;
 
-	g_free (str);
+	g_string_free (str, TRUE);
 }
 
 static void
@@ -622,6 +641,7 @@ status_icon_event_new (EmpathyStatusIcon *icon,
 						     (GSourceFunc) status_icon_event_timeout_cb,
 						     icon);
 		status_icon_event_timeout_cb (icon);
+		status_icon_update_tooltip (icon);
 	}
 
 	return event;
@@ -671,7 +691,6 @@ status_icon_event_timeout_cb (EmpathyStatusIcon *icon)
 		event = priv->events->data;
 		gtk_status_icon_set_from_icon_name (priv->icon, event->icon_name);
 	}
-	status_icon_update_tooltip (icon);
 
 	return TRUE;
 }
