@@ -17,6 +17,9 @@ GType empathy_message_type_get_type (void);
 #include <libempathy/empathy-contact.h>
 #define EMPATHY_TYPE_CAPABILITIES empathy_capabilities_get_type()
 GType empathy_capabilities_get_type (void);
+#include <libempathy/empathy-tp-call.h>
+#define EMPATHY_TYPE_TP_CALL_STATUS empathy_tp_call_status_get_type()
+GType empathy_tp_call_status_get_type (void);
 G_END_DECLS
 
 #endif /* __LIBEMPATHY_ENUM_TYPES_H__ */
